@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import marshmallow as ma
 from marshmallow.compat import with_metaclass, iteritems
-from sqlalchemy.ext.associationproxy import AssociationProxy
 
 from .convert import ModelConverter
 from .fields import get_primary_keys
@@ -56,16 +55,15 @@ class SchemaMeta(ma.schema.SchemaMeta):
         """Updates declared fields with fields converted from the SQLAlchemy model
         passed as the `model` class Meta option.
         """
-        declared_fields = dict_cls()
         opts = klass.opts
         Converter = opts.model_converter
         converter = Converter(schema_cls=klass)
-        base_fields = super(SchemaMeta, mcs).get_declared_fields(
+        declared_fields = super(SchemaMeta, mcs).get_declared_fields(
             klass, cls_fields, inherited_fields, dict_cls
         )
-        declared_fields = mcs.get_fields(converter, opts, base_fields, dict_cls)
-        declared_fields.update(base_fields)
-        return declared_fields
+        fields = mcs.get_fields(converter, opts, declared_fields, dict_cls)
+        fields.update(declared_fields)
+        return fields
 
     @classmethod
     def get_fields(mcs, converter, base_fields, opts):
@@ -240,7 +238,8 @@ class ModelSchema(with_metaclass(ModelSchemaMeta, ma.Schema)):
         association_attrs = {
             key: value
             for key, value in iteritems(data)
-            if isinstance(getattr(self.opts.model, key, None), AssociationProxy)
+            # association proxy
+            if hasattr(getattr(self.opts.model, key, None), "remote_attr")
         }
         kwargs = {
             key: value
